==> docrepo-0.8.1.tar.gz: docrepo-0.8.1/README.md <==

[![Build Status](https://travis-ci.com/TralahM/docrepo.svg?branch=master)](https://travis-ci.com/TralahM/docrepo)
[![Documentation Status](https://readthedocs.org/projects/docrepo/badge/?version=latest)](https://docrepo.readthedocs.io/en/latest/?badge=latest)
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)
[![Organization](https://img.shields.io/badge/Org-TralahTek-blue.svg)](https://github.com/TralahTek)
[![Views](http://hits.dwyl.io/TralahM/docrepo.svg)](http://dwyl.io/TralahM/docrepo)
[![PRs Welcome](https://img.shields.io/badge/PRs-Welcome-brightgreen.svg?style=flat-square)](https://github.com/TralahM/docrepo/pull/)
[![GitHub pull-requests](https://img.shields.io/badge/Issues-pr-red.svg?style=flat-square)](https://github.com/TralahM/docrepo/pull/)
[![Language](https://img.shields.io/badge/Language-Python-3572A5.svg)](https://github.com/TralahM)

# docrepo.


[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-black.svg?style=for-the-badge)](https://github.com/TralahTek)
[![TralahM](https://img.shields.io/badge/Engineer-TralahM-blue.svg?style=for-the-badge)](https://github.com/TralahM)
[![TralahM](https://img.shields.io/badge/Maintainer-TralahM-green.svg?style=for-the-badge)](https://github.com/TralahM)

# Documentation

This is an Improvement of the initgitdoc version of the library on [pypi](https://pypi.org/projects/initgitdoc).

So for the latest version don't `pip install initgitdoc` rather `pip install docrepo`

This version Maintains Backward Compatibility with initgitdoc so the older scripts still work.

I have decided to drop maintenance for the older pypi version in favour of this

[![Documentation](https://img.shields.io/badge/Docs-docrepo-blue.svg?style=for-the-badge)](https://github.com/TralahM/docrepo)

# How to Install
```bash
# In terminal do:
$ pip install docrepo
$ docrepo --help
```

## Building from Source for Developers

```console
$ git clone https://github.com/TralahM/docrepo.git
$ cd docrepo
$ python setup.py install
```

# Contributing
[See the Contributing File](CONTRIBUTING.rst)


[See the Pull Request File](PULL_REQUEST_TEMPLATE.md)


# Support

# LICENCE

[Read the license here](LICENSE)


# Self-Promotion

[![TralahM](https://img.shields.io/badge/Twitter-TralahM-blue.svg?style=for-the-badge)](https://twitter.com/TralahM)
[![TralahM](https://img.shields.io/badge/Github-TralahM-black.svg?style=for-the-badge)](https://github.com/TralahM)
[![TralahM](https://img.shields.io/badge/Kaggle-TralahM-purple.svg?style=for-the-badge)](https://kaggle.com/TralahM)
[![TralahM](https://img.shields.io/badge/LinkedIn-TralahM-red.svg?style=for-the-badge)](https://linkedin.com/in/TralahM)
[![Blog](https://img.shields.io/badge/Blog-tralahm.tralahtek.com-blue.svg?style=for-the-badge)](https://tralahm.tralahtek.com)
[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-cyan.svg?style=for-the-badge)](https://tralahtek.com)

==> docrepo-0.8.3.tar.gz: docrepo-0.8.3/README.md <==

[![Codacy Badge](https://api.codacy.com/project/badge/Grade/edee62dc5e124931bc3d7b2ee29f2435)](https://app.codacy.com/manual/musyoki.tralah/docrepo?utm_source=github.com&utm_medium=referral&utm_content=TralahM/docrepo&utm_campaign=Badge_Grade_Dashboard)
[![Build Status](https://travis-ci.com/TralahM/docrepo.svg?branch=master)](https://travis-ci.com/TralahM/docrepo)
[![Documentation Status](https://readthedocs.org/projects/docrepo/badge/?version=latest)](https://docrepo.readthedocs.io/en/latest/?badge=latest)
[![License: MIT](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)
[![Organization](https://img.shields.io/badge/Org-TralahTek-blue.svg)](https://github.com/TralahTek)
[![Views](http://hits.dwyl.io/TralahM/docrepo.svg)](http://dwyl.io/TralahM/docrepo)
[![PRs Welcome](https://img.shields.io/badge/PRs-Welcome-brightgreen.svg?style=flat-square)](https://github.com/TralahM/docrepo/pull/)
[![GitHub pull-requests](https://img.shields.io/badge/Issues-pr-red.svg?style=flat-square)](https://github.com/TralahM/docrepo/pull/)
[![Language](https://img.shields.io/badge/Language-Python-3572A5.svg)](https://github.com/TralahM)

# docrepo.


[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-black.svg?style=for-the-badge)](https://github.com/TralahTek)
[![TralahM](https://img.shields.io/badge/Engineer-TralahM-blue.svg?style=for-the-badge)](https://github.com/TralahM)
[![TralahM](https://img.shields.io/badge/Maintainer-TralahM-green.svg?style=for-the-badge)](https://github.com/TralahM)

# Documentation

This is an Improvement of the initgitdoc version of the library on [pypi](https://pypi.org/projects/initgitdoc).

So for the latest version don't `pip install initgitdoc` rather `pip install docrepo`

This version Maintains Backward Compatibility with initgitdoc so the older scripts still work.

I have decided to drop maintenance for the older pypi version in favour of this

[![Documentation](https://img.shields.io/badge/Docs-docrepo-blue.svg?style=for-the-badge)](https://github.com/TralahM/docrepo)

# How to Install
```bash
# In terminal do:
$ pip install docrepo
$ docrepo --help
```

## Building from Source for Developers

```console
$ git clone https://github.com/TralahM/docrepo.git
$ cd docrepo
$ python setup.py install
```

# Contributing
[See the Contributing File](CONTRIBUTING.rst)


[See the Pull Request File](PULL_REQUEST_TEMPLATE.md)


# Support

# LICENCE

[Read the license here](LICENSE)


# Self-Promotion

[![TralahM](https://img.shields.io/badge/Twitter-TralahM-blue.svg?style=for-the-badge)](https://twitter.com/TralahM)
[![TralahM](https://img.shields.io/badge/Github-TralahM-black.svg?style=for-the-badge)](https://github.com/TralahM)
[![TralahM](https://img.shields.io/badge/Kaggle-TralahM-purple.svg?style=for-the-badge)](https://kaggle.com/TralahM)
[![TralahM](https://img.shields.io/badge/LinkedIn-TralahM-red.svg?style=for-the-badge)](https://linkedin.com/in/TralahM)
[![Blog](https://img.shields.io/badge/Blog-tralahm.tralahtek.com-blue.svg?style=for-the-badge)](https://tralahm.tralahtek.com)
[![TralahTek](https://img.shields.io/badge/Organization-TralahTek-cyan.svg?style=for-the-badge)](https://tralahtek.com)
